@@ -80,10 +80,6 @@
 #'   vocalTract = 16, plot = TRUE, lipRad = 6, noseRad = 4,
 #'   mouth = data.frame(time = c(0, .5, 1), value = c(0, 0, .5)))
 #'
-#' # dynamic VTL
-#' e = getSpectralEnvelope(nr = 512, nc = 50, formants = 'a',
-#'   vocalTract = c(15, 17.5, 18), plot = TRUE)
-#'
 #' # scale formant amplitude and/or bandwidth
 #' e1 = getSpectralEnvelope(nr = 512, nc = 50,
 #'   formants = soundgen:::convertStringToFormants('a'),
@@ -91,8 +87,8 @@
 #' e2 = getSpectralEnvelope(nr = 512, nc = 50,
 #'   formants = soundgen:::convertStringToFormants('a'),
 #'   formantWidth = 1.5, formantDep = 1.5)
-#' plot(e2[, 1], type = 'l', col = 'red', lty = 2)
-#' points(e1[, 1], type = 'l')
+#' plot(20 * log10(e2[, 1]), type = 'l', col = 'red', lty = 2)
+#' points(20 * log10(e1[, 1]), type = 'l')
 #'
 #' # manual specification of formants
 #' e = getSpectralEnvelope(nr = 512, nc = 50, plot = TRUE, samplingRate = 16000,
@@ -363,7 +359,7 @@ getSpectralEnvelope = function(nr,
         # we add half that value as the mouth goes from neutral to max open. NB:
         # so "closed" is actually "half-closed", and we assume that nostrils are
         # always open (so not really a closed-closed tube)
-        adjustment_bins = (adjustment_hz - bin_width / 2) / bin_width + 1
+        adjustment_bins = adjustment_hz / bin_width # (adjustment_hz - bin_width / 2) / bin_width + 1
       }
     }
     for (f in 1:length(formants_upsampled)) {
@@ -703,7 +699,7 @@ reformatFormants = function(formants,
       stop('If defined, formants must be either a list or a string of characters
          from dictionary presets: a, o, i, e, u, 0 (schwa)')
     } else {
-    return(NA)
+      return(NA)
     }
   }
 
@@ -1411,10 +1407,12 @@ lockToFormants = function(pitch,
   }
   n = length(pitch)
   if (is.list(lockProb)) {
-    lockProb = getSmoothContour(anchors = lockProb,
-                                len = n,
-                                valueFloor = permittedValues['formantLocking', 'low'],
-                                valueCeiling = permittedValues['formantLocking', 'high'])
+    lockProb = getSmoothContour(
+      anchors = lockProb,
+      len = n,
+      valueFloor = permittedValues['formantLocking', 'low'],
+      valueCeiling = permittedValues['formantLocking', 'high']
+    )
   }
   freqs = as.numeric(rownames(specEnv)) * 1000
   specEnv = interpolMatrix(
