@@ -52,19 +52,17 @@
 #' @param maxFreq parts of the spectra above \code{maxFreq} Hz are not compared
 #' @export
 #' @examples
-#' playback = c(TRUE, FALSE)[2]  # set to TRUE to play back the audio from examples
-#'
+#' \dontrun{
 #' target = soundgen(repeatBout = 3, sylLen = 120, pauseLen = 70,
-#'   pitch = c(300, 200), rolloff = -5, play = playback)
+#'   pitch = c(300, 200), rolloff = -5, play = TRUE)
 #' # we hope to reproduce this sound
 #'
-#' \dontrun{
 #' # Match pars based on acoustic analysis alone, without any optimization.
 #' # This *MAY* match temporal structure, pitch, and stationary formants
 #' m1 = matchPars(target = target,
 #'                samplingRate = 16000,
 #'                maxIter = 0,  # no optimization, only acoustic analysis
-#'                verbose = playback)
+#'                verbose = TRUE)
 #' cand1 = do.call(soundgen, c(m1$pars, list(play = playback, temperature = 0.001)))
 #'
 #' # Try to improve the match by optimizing rolloff
@@ -73,7 +71,7 @@
 #'                samplingRate = 16000,
 #'                pars = 'rolloff',
 #'                maxIter = 100,
-#'                verbose = playback)
+#'                verbose = TRUE)
 #' # rolloff should be moving from default (-9) to target (-5):
 #' sapply(m2$history, function(x) x$pars$rolloff)
 #' cand2 = do.call(soundgen, c(m2$pars, list(play = playback, temperature = 0.001)))
@@ -139,10 +137,10 @@ matchPars = function(target,
   p = as.numeric(na.omit(aa$pitch))
   p = downsample(p, srNew = 5, srOld = 1 / step * 1000)  # downsample F0 measures to 5 Hz
   if (length(p) > 1) {
-    parDefault$pitch = data.frame(
+    parDefault$pitch = list(
       time = round(seq(0, 1, length.out = length(p)), 2),
       value = round(p)
-    )}
+  )}
   if (is.list(af)) {
     if (nrow(af) > 0) {
       for (f in 1:min(3, nrow(af))) {  # add max 3 formants
@@ -273,7 +271,7 @@ matchPars = function(target,
 #'                                      value = c(100, 150, 135, 100)),
 #'                   temperature = 0.001)
 #' targetSpec = soundgen:::getMelSpec(target, samplingRate = 16000)
-
+#'
 #' parsToTry = list(
 #'   list(formants = 'i',                                            # wrong
 #'        pitch = data.frame(time = c(0, 1),                         # wrong
