@@ -4,19 +4,20 @@
 #' modulation along the X axis (Hz) and spectral modulation (1/KHz) along the Y
 #' axis. A good visual analogy is decomposing the spectrogram into a sum of
 #' ripples of various frequencies and directions. Algorithm: prepare a
-#' \code{\link{spectrogram}}, take its logarithm (if \code{logSpec = TRUE}),
-#' center, perform a 2D Fourier transform (see also spec.fft() in the "spectral"
-#' package), take the upper half of the resulting symmetric matrix, and raise it
-#' to \code{power}. The result is returned as \code{$original}. Roughness is
-#' calculated as the proportion of energy / amplitude of the modulation spectrum
-#' within \code{roughRange} of temporal modulation frequencies. By default, the
-#' modulation matrix is then smoothed with Gaussian blur (see
-#' \code{\link{gaussianSmooth2D}}) and log-warped (if \code{logWarp} is a
-#' positive number) prior to plotting. This processed modulation spectrum is
-#' returned as \code{$processed}. For multiple inputs, such as a list of
-#' waveforms or path to a folder with audio files, the ensemble of modulation
-#' spectra is interpolated to the same spectral and temporal resolution and
-#' averaged. This is different from the behavior of
+#' spectrogram, take its logarithm (if \code{logSpec = TRUE}), center, perform a
+#' 2D Fourier transform (see also spectral::spec.fft()), take the upper half of
+#' the resulting symmetric matrix, and raise it to \code{power}. The result is
+#' returned as \code{$original}. Roughness is calculated as the proportion of
+#' energy / amplitude of the modulation spectrum within \code{roughRange} of
+#' temporal modulation frequencies. For plotting purposes, the modulation matrix
+#' is smoothed with Gaussian blur (see \code{\link{gaussianSmooth2D}}) and
+#' log-warped (if \code{logWarp} is a positive number). This processed
+#' modulation spectrum is returned as \code{$processed}. If the audio is long
+#' enough, multiple windows are analyzed, resulting in a vector of roughness
+#' values. For multiple inputs, such as a list of waveforms or path to a folder
+#' with audio files, the ensemble of modulation spectra is interpolated to the
+#' same spectral and temporal resolution and averaged, resulting in a single
+#' roughness value. This is different from the behavior of
 #' \code{\link{modulationSpectrumFolder}}, which produces a separate modulation
 #' spectrum per file, without averaging.
 #'
@@ -35,8 +36,13 @@
 #' @param roughRange the range of temporal modulation frequencies that
 #'   constitute the "roughness" zone, Hz
 #' @inheritParams spectrogram
+#' @param amRes target resolution of amplitude modulation, Hz. If \code{NULL},
+#'   the entire sound is analyzed at once (or in chunks \code{maxDur} s long),
+#'   resulting in a single roughness value. Otherwise, roughness is calculated
+#'   per frame, each selected to contain enough STFT windows to calculate
+#'   roughness with precision given by \code{amRes}
 #' @param maxDur maximum allowed duration of a single sound, s (longer sounds
-#'   are split)
+#'   are split, and their modulation spectra averaged)
 #' @param logSpec if TRUE, the spectrogram is log-transformed prior to taking 2D
 #'   FFT
 #' @param power raise modulation spectrum to this power (eg power = 2 for ^2, or
@@ -47,7 +53,7 @@
 #'   otherwise returns the complex MS of the first input (recommended when
 #'   filtering and inverting the MS of a single sound, e.g. with
 #'   \code{\link{filterSoundByMS}})
-#' @param plot if TRUE, plots the modulation spectrum
+#' @param plot if TRUE, plots the (averaged) modulation spectrum
 #' @param savePath if a valid path is specified, a plot is saved in this folder
 #'   (defaults to NA)
 #' @param logWarp the base of log for warping the modulation spectrum (ie log2
@@ -58,7 +64,7 @@
 #'   smoothing)
 #' @param kernelSD the SD of Gaussian kernel used for smoothing, relative to its
 #' size
-#' @param xlab,ylab,main graphical parameters
+#' @param xlab,ylab,main,xlim,ylim graphical parameters
 #' @param width,height,units,res parameters passed to
 #'   \code{\link[grDevices]{png}} if the plot is saved
 #' @param ... other graphical parameters passed on to \code{filled.contour.mod}
@@ -71,26 +77,37 @@
 #' temporal modulation frequencies (Hz).
 #' \item \code{$processed} modulation spectrum after blurring and log-warping
 #' \item \code{$roughness} proportion of energy / amplitude of the modulation
-#' spectrum within \code{roughRange} of temporal modulation frequencies, \%
+#' spectrum within \code{roughRange} of temporal modulation frequencies, \% - a
+#' vector if amRes is numeric and the sound is long enough, a single number
+#' otherwise
 #' \item \code{$complex} untransformed complex modulation spectrum (returned
 #' only if returnComplex = TRUE)
 #' }
 #' @export
 #' @examples
-#' # white noise
+#' # White noise
 #' ms = modulationSpectrum(runif(16000), samplingRate = 16000,
 #'   logSpec = FALSE, power = TRUE)
 #'
-#' # harmonic sound
+#' # Harmonic sound
 #' s = soundgen()
-#' ms = modulationSpectrum(s, samplingRate = 16000,
-#'   logSpec = FALSE, power = TRUE)
+#' ms = modulationSpectrum(s, samplingRate = 16000)
+#' ms$roughness  # roughness over time
 #'
-#' # embellish
+#' # A single roughness measure per sound
+#' modulationSpectrum(s, samplingRate = 16000, amRes = NULL)$roughness
+#'
+#' # Embellish
 #' ms = modulationSpectrum(s, samplingRate = 16000,
 #'   xlab = 'Temporal modulation, Hz', ylab = 'Spectral modulation, 1/KHz',
 #'   colorTheme = 'heat.colors', main = 'Modulation spectrum', lty = 3)
+#'
 #' \dontrun{
+#' # Roughness contour of a long sound (starts tonal, then gets rough)
+#' s_long = soundgen(sylLen = 4000, pitch = 400, plot = TRUE,
+#'   amDep = c(0, 0, 50), jitterDep = c(0, 0, 2))
+#' modulationSpectrum(s_long, 16000, plot = FALSE)$roughness
+#'
 #' # Input can also be a list of waveforms (numeric vectors)
 #' ss = vector('list', 10)
 #' for (i in 1:length(ss)) {
@@ -115,27 +132,30 @@
 #' s = soundgen(pitch = 500, amFreq = 50, amDep = 100, samplingRate = 44100)
 #' # playme(s, samplingRate = 44100)
 #' ms = modulationSpectrum(s, samplingRate = 44100,
-#'   windowLength = 50, overlap = 0)  # poor temporal resolution
+#'   windowLength = 50, overlap = 0, amRes = NULL)  # poor temporal resolution
 #' ms = modulationSpectrum(s, samplingRate = 44100,
-#'   windowLength = 5, overlap = 80)  # poor frequency resolution
+#'   windowLength = 5, overlap = 80, amRes = NULL)  # poor frequency resolution
 #' ms = modulationSpectrum(s, samplingRate = 44100,
-#'   windowLength = 15, overlap = 80)  # a reasonable compromise
+#'   windowLength = 15, overlap = 80, amRes = NULL)  # a reasonable compromise
 #'
 #' # customize the plot
 #' ms = modulationSpectrum(s, samplingRate = 44100,
+#'   windowLength = 15, overlap = 80, amRes = NULL,
 #'   kernelSize = 17,  # more smoothing
-#'   xlim = c(-20, 20), ylim = c(0, 4),  # zoom in on the central region
+#'   xlim = c(-70, 70), ylim = c(0, 4),  # zoom in on the central region
 #'   quantiles = c(.25, .5, .8),  # customize contour lines
 #'   colorTheme = 'heat.colors',  # alternative palette
 #'   power = 2)                   # ^2
-#' # NB: xlim/ylim currently won't work properly with logWarp on
+#' # Note the peaks at FM = 2/KHz (from "pitch = 500") and AM = 50 Hz (from
+#' # "amFreq = 50")
 #'
 #' # Input can be a wav/mp3 file
 #' ms = modulationSpectrum('~/Downloads/temp/200_ut_fear-bungee_11.wav')
 #'
 #' # Input can be path to folder with audio files (average modulation spectrum)
 #' ms = modulationSpectrum('~/Downloads/temp', kernelSize = 11)
-#' # NB: longer files will be split into fragments <maxDur in length
+#' # NB: longer files will be split into fragments <maxDur in length, and no
+#' # roughness contours are extracted
 #'
 #' # A sound with ~3 syllables per second and only downsweeps in F0 contour
 #' s = soundgen(nSyl = 8, sylLen = 200, pauseLen = 100, pitch = c(300, 200))
@@ -177,6 +197,7 @@
 modulationSpectrum = function(
   x,
   samplingRate = NULL,
+  amRes = 5,
   maxDur = 5,
   logSpec = FALSE,
   windowLength = 25,
@@ -198,6 +219,8 @@ modulationSpectrum = function(
   xlab = 'Hz',
   ylab = '1/KHz',
   main = NULL,
+  xlim = NULL,
+  ylim = NULL,
   width = 900,
   height = 500,
   units = 'px',
@@ -279,25 +302,68 @@ modulationSpectrum = function(
   windowLength_points = round(windowLength / 1000 * samplingRate)
   windowLength = windowLength_points[1] / samplingRate[1] * 1000
   overlap = 100 * (1 - step_points[1] / windowLength_points[1])
+  sr = max(samplingRate)  # again, in case not the same
 
-  # split sounds that exceed maxDur
-  toSplit = which(duration > maxDur)
-  if (length(toSplit) > 0) {
-    splitInto = ceiling(duration / maxDur)
-    # so, for ex., if 2.1 times longer than maxDur, split into three
-    for (i in toSplit) {
-      idx = floor(seq(1, length(myInput[[i]]), length.out = splitInto[i] + 1))
-      for (j in 2:splitInto[i]) {
-        # append fragments 2-end to myInput
-        start = idx[j] + 1
-        end = idx[j + 1]
-        myInput[[length(myInput) + 1]] = myInput[[i]][start:end]
-        samplingRate = c(samplingRate, samplingRate[i])
-        windowLength_points = c(windowLength_points, windowLength_points[length(windowLength_points)])
-        step_points = c(step_points, step_points[length(step_points)])
+  max_am = 1000 / step / 2
+  if (max_am < roughRange[1]) {
+    warning(paste(
+      'roughRange outside the analyzed range of temporal modulation frequencies;',
+      'increase overlap / decrease step to improve temporal resolution,',
+      'or else look for roughness in a lower range'))
+  }
+  if (is.numeric(amRes)) {
+    nFrames = ceiling(max_am / amRes * 2)
+  } else {
+    nFrames = NULL
+  }
+
+  if (length(myInput) == 1 & is.numeric(nFrames)) {
+    # one input, we want roughness contour
+    roughContour = TRUE
+
+    # split the input sound into chunks nFrames long
+    chunk_ms = windowLength + step * (nFrames - 1)
+    l = chunk_ms * samplingRate / 1000
+    fullSound = myInput[[1]]
+    l_full = length(fullSound)
+    if (l > l_full) {
+      message(paste('The sound is too short to be analyzed with amRes =', amRes,
+                    'Hz. Roughness is probably not measured correctly'))
+      l = l_full
+    }
+    myseq = 1 + l * (0:(floor(l_full / l) - 1))
+    myInput = vector('list', length(myseq))
+    n = length(myInput)
+    for (i in 1:n) {
+      idx = myseq[i]:(myseq[i] + l - 1)
+      myInput[[i]] = fullSound[idx]
+    }
+    windowLength_points = rep(windowLength_points, n)
+    step_points = rep(step_points, n)
+    samplingRate = rep(samplingRate, n)
+  } else {
+    # multiple inputs to aggregate and/or we want a single roughness value
+    roughContour = FALSE
+
+    # split sounds that exceed maxDur
+    toSplit = which(duration > maxDur)
+    if (length(toSplit) > 0) {
+      splitInto = ceiling(duration / maxDur)
+      # so, for ex., if 2.1 times longer than maxDur, split into three
+      for (i in toSplit) {
+        idx = floor(seq(1, length(myInput[[i]]), length.out = splitInto[i] + 1))
+        for (j in 2:splitInto[i]) {
+          # append fragments 2-end to myInput
+          start = idx[j] + 1
+          end = idx[j + 1]
+          myInput[[length(myInput) + 1]] = myInput[[i]][start:end]
+          samplingRate = c(samplingRate, samplingRate[i])
+          windowLength_points = c(windowLength_points, windowLength_points[length(windowLength_points)])
+          step_points = c(step_points, step_points[length(step_points)])
+        }
+        # the first fragment replaces the old long sound in myInput
+        myInput[[i]] = myInput[[i]][1:idx[2]]
       }
-      # the first fragment replaces the old long sound in myInput
-      myInput[[i]] = myInput[[i]][1:idx[2]]
     }
   }
 
@@ -309,28 +375,23 @@ modulationSpectrum = function(
     out_aggreg_complex = NULL
   }
   for (i in 1:length(myInput)) {
-    # s1 = spectrogram(myInput[[i]],
-    #                  samplingRate = samplingRate[i],
-    #                  windowLength = windowLength,
-    #                  step = step,
-    #                  wn = wn,
-    #                  zp = zp,
-    #                  plot = FALSE,
-    #                  output = 'original',
-    #                  padWithSilence = FALSE,
-    #                  normalize = TRUE)
     # Calling stdft is ~80 times faster than going through spectrogram (!)
     step_seq = seq(1, length(myInput[[i]]) + 1 - windowLength_points[i], step_points[i])
-    s1 = seewave::stdft(wave = as.matrix(myInput[[i]]),
-                        wn = wn,
-                        wl = windowLength_points[i],  # for multiple inputs, samplingRate, wl etc can vary
-                        f = samplingRate[i],
-                        zp = zp,
-                        step = step_seq,
-                        scale = TRUE,
-                        norm = FALSE,
-                        complex = FALSE)
+    # print(length(step_seq))
+    if (length(step_seq) < 3) next
+    s1 = seewave::stdft(
+      wave = as.matrix(myInput[[i]]),
+      wn = wn,
+      wl = windowLength_points[i],  # for multiple inputs, samplingRate, wl etc can vary
+      f = samplingRate[i],
+      zp = zp,
+      step = step_seq,
+      scale = FALSE,
+      norm = FALSE,
+      complex = FALSE
+    )
     # image(t(log(s1))); s1[1:3, 1:3]; dim(s1); range(s1)
+
     # log-transform amplitudes
     if (logSpec) {
       positives = which(s1 > 0)
@@ -340,23 +401,25 @@ modulationSpectrum = function(
         s1[nonpositives] = min(s1[positives])
       }
       s1 = s1 - min(s1) + 1e-16  # positive
-      # s1 = log(s1 + 1e-16)
-      # s1 = s1 - min(s1) + 1e-16  # positive
+      # image(t(log(s1)))
     }
+
     # 2D fft
     ms_complex = specToMS(s1, windowLength = windowLength, step = step)
     ms = abs(ms_complex)
-    # image(t(log(ms)))
+    # image(as.numeric(colnames(ms)), as.numeric(rownames(ms)), t(log(ms)))
     symAxis = floor(nrow(ms) / 2) + 1
     # ms[(symAxis - 2) : (symAxis + 2), 1:2]
-    ms_half = ms[symAxis:nrow(ms), ]  # take only the upper half (always even)
+    ms_half = ms[symAxis:nrow(ms),, drop = FALSE]  # take only the upper half (always even)
 
     # power
     if (is.numeric(power) && power != 1) ms_half = ms_half ^ power
 
     # normalize
-    ms_half = ms_half - min(ms_half)
-    ms_half = ms_half / max(ms_half)
+    if (any(s1 != 0)) {
+      ms_half = ms_half - min(ms_half)
+      ms_half = ms_half / max(ms_half)
+    }
     # image(x = as.numeric(colnames(ms_half)), z = t(log(ms_half)))
     out[[i]] = ms_half
 
@@ -365,29 +428,26 @@ modulationSpectrum = function(
     }
   }
 
+  keep = which(unlist(lapply(out, function(x) !is.null(x))))
+  out = out[keep]
+  if (length(out) < 1) {
+    warning('The sound is too short or windowLength too long. Need at least 3 frames')
+    return(list('original' = NA,
+                'processed' = NA,
+                'complex' = NA,
+                'roughness' = NA))
+  }
+
   # average modulation spectra across all sounds
   max_rows = max(unlist(lapply(out, nrow)))
   # normally same samplingRate, but in case not, upsample frequency resolution
   # typical ncol (depends on sound dur)
   typicalCols = round(median(unlist(lapply(out, ncol))))
-  sr = max(samplingRate)  # again, in case not the same
   out1 = lapply(out, function(x) interpolMatrix(x, nr = max_rows, nc = typicalCols))
   out_aggreg = Reduce('+', out1) / length(myInput)
-  # image(x = as.numeric(colnames(out_aggreg)), z = t(log(out_aggreg)))
-
-  # get time and frequency labels
-  max_am = 1000 / step / 2
-  if (max_am < roughRange[1]) {
-    warning(paste(
-      'roughRange outside the analyzed range of temporal modulation frequencies;',
-      'increase overlap / decrease step to improve temporal resolution,',
-      'or else look for roughness in a lower range'))
-  }
-  X = seq(-max_am, max_am, length.out = ncol(out_aggreg))  # time modulation
-  max_fm = nrow(out_aggreg) / (sr / 2 / 1000)
-  Y = seq(max_fm / nrow(out_aggreg), max_fm, length.out = nrow(out_aggreg))  # frequency modulation
-  rownames(out_aggreg) = Y
-  colnames(out_aggreg) = X
+  X = as.numeric(colnames(out_aggreg))
+  Y = as.numeric(rownames(out_aggreg))
+  # image(X, Y, t(log(out_aggreg)))
 
   # prepare a separate summary of the complex ms
   if (returnComplex) {
@@ -405,19 +465,28 @@ modulationSpectrum = function(
   }
 
   # extract a measure of roughness
-  roughness = getRough(out_aggreg, roughRange)
+  if (roughContour) {
+    roughness = unlist(lapply(out, function(x)
+      getRough(x, roughRange, colNames = as.numeric(colnames(out[[1]])))))
+  } else {
+    roughness = getRough(out_aggreg, roughRange, colNames = X)
+  }
 
   # log-transform the axes (or, actually, warps the matrix itself)
   if (is.numeric(logWarp)) {
-    zero_col = ceiling(ncol(out_aggreg) / 2)
-    m_left = logMatrix(out_aggreg[, zero_col:1], base = logWarp)  # NB: flip the left half!
-    m_right = logMatrix(out_aggreg[, zero_col:ncol(out_aggreg)], base = logWarp)
-    out_transf = cbind(m_left[, ncol(m_left):1], m_right[, 2:ncol(m_right)])
+    neg_col = which(X < 0)
+    zero_col = which(X == 0)
+    pos_col = which(X > 0)
+    m_left = logMatrix(out_aggreg[, rev(neg_col)], base = logWarp)
+    # NB: flip the left half!
+    m_right = logMatrix(out_aggreg[, pos_col], base = logWarp)
+    out_transf = cbind(m_left[, ncol(m_left):1], out_aggreg[, zero_col, drop = FALSE], m_right)
     X1 = as.numeric(colnames(out_transf))  # warped by logMatrix
     Y1 = as.numeric(rownames(out_transf))  # warped by logMatrix
   } else {
     out_transf = out_aggreg
   }
+  # image(out_transf)
 
   # smoothing / blurring
   out_transf = gaussianSmooth2D(out_transf,
@@ -439,6 +508,8 @@ modulationSpectrum = function(
 
   if (plot) {
     color.palette = switchColorTheme(colorTheme)
+    if (is.null(xlim)) xlim = c(X[1], -X[1])
+    if (is.null(ylim)) ylim = range(Y)
     if (is.numeric(logWarp)) {
       filled.contour.mod(
         x = X, y = Y, z = t(out_transf),
@@ -447,32 +518,18 @@ modulationSpectrum = function(
         xlab = xlab, ylab = ylab,
         bty = 'n', axisX = FALSE, axisY = FALSE,
         main = plotname,
+        xlim = xlim, ylim = ylim,
         ...
       )
       # add manually labeled x-axis
-      w = which.min(abs(X))  # should be 0 or nearly 0
-      xseq = round(seq(w, length(X), length.out = min(4, floor(length(X) / 2))))
-      # make sure the same numbers are at left & right
-      xseq = c(rev(w - (xseq[2:length(xseq)] - w)), xseq)
-      digits = 0  # choosing the optimal rounding level
-      rx = round(X1[xseq], digits = digits)
-      while (length(rx) > length(unique(rx))) {  # eg it starts 0, 0, 1, ...
-        digits = digits + 1
-        rx = round(X1[xseq], digits = digits)  # thus 0.2, 0.4, 1.1, ...
-      }
+      max_tm = log(-X[1], logWarp)
+      xl = unique(round(logWarp ^ pretty(c(1, max_tm), n = 4)))
+      xl = c(-rev(xl), 0, xl)
+      xl = xl[abs(xl) < -X1[1]]
+      pos = apply(matrix(xl), 1, function(x) which.min(abs(x - X1)))
       axis(side = 1,
-           at  = round(X[xseq]),
-           labels = rx)
-      # max_tm = log(X[length(X)], logWarp)
-      # xl = logWarp ^ pretty(c(1, max_tm), n = 7)
-      # xl = unique(round(c(0, xl[xl < X[length(X)]])))
-      # xl1 = xl
-      # for (i in 1:length(xl)) {
-      #   xl1[i] = X[which.min(abs(X1 - xl[i]))]
-      # }
-      # axis(side = 1,
-      #      at  = xl1,
-      #      labels = xl)
+           at  = X[pos],
+           labels = xl)
 
       # add manually labeled y-axis
       yseq = seq(1, length(Y), length.out = 7)
@@ -501,10 +558,9 @@ modulationSpectrum = function(
         levels = seq(0, 1, length = 30),
         color.palette = color.palette,
         xlab = xlab, ylab = ylab,
-        bty = 'n', ...
+        bty = 'n', xlim = xlim, ylim = ylim, ...
       )
     }
-
     abline(v = 0, lty = 3)
     # qntls = quantile(out_aggreg, probs = quantiles)  # could try HDI instead
     qntls = pDistr(as.numeric(out_transf), quantiles = quantiles)
@@ -513,7 +569,7 @@ modulationSpectrum = function(
             levels = qntls, labels = quantiles * 100,
             xaxs = 'i', yaxs = 'i',
             axes = FALSE, frame.plot = FALSE,
-            main = plotname, ...)
+            main = plotname, xlim = xlim, ylim = ylim, ...)
     par(new = FALSE)
     if (is.character(savePath)) dev.off()
   }
@@ -537,20 +593,22 @@ modulationSpectrum = function(
 #' @inheritParams analyzeFolder
 #' @inheritParams modulationSpectrum
 #' @inheritParams spectrogram
-#' @return If \code{summary} is TRUE, returns a dataframe with just the
-#'   roughness measure per audio file. If \code{summary} is FALSE, returns a
-#'   list with the actual modulation spectra.
+#' @return If \code{summaryFun} is defined, returns a dataframe with just
+#'   roughness per audio file, otherwise returns a list with the actual
+#'   modulation spectra.
 #' @export
 #' @examples
 #' \dontrun{
 #' ms = modulationSpectrumFolder('~/Downloads/temp', savePlots = TRUE,
 #'                               kernelSize = 15)
+#' ms
 #' }
 modulationSpectrumFolder = function(
   myfolder,
-  summary = TRUE,
+  summaryFun = c('mean', 'sd'),
   htmlPlots = TRUE,
   verbose = TRUE,
+  amRes = 5,
   maxDur = 5,
   logSpec = FALSE,
   windowLength = 25,
@@ -577,6 +635,7 @@ modulationSpectrumFolder = function(
 ) {
   time_start = proc.time()  # timing
   filenames = list.files(myfolder, pattern = "*.wav|.mp3|.WAV|.MP3", full.names = TRUE)
+  filenames_base = basename(filenames)
   if (length(filenames) < 1) {
     stop(paste('No wav/mp3 files found in', myfolder))
   }
@@ -588,10 +647,12 @@ modulationSpectrumFolder = function(
   myPars = mget(names(formals()), sys.frame(sys.nframe()))
   # exclude some args
   myPars = myPars[!names(myPars) %in% c(
-    'myfolder' , 'htmlPlots', 'verbose', 'savePlots', 'summary')]
+    'myfolder' , 'htmlPlots', 'verbose', 'savePlots', 'summaryFun')]
   # exclude ...
   myPars = myPars[1:(length(myPars)-1)]
   if (savePlots) myPars$savePath = myfolder
+  if (is.null(amRes)) summaryFun = 'identity'
+  # nothing to summarize - 1 value per file
 
   result = list()
   for (i in 1:length(filenames)) {
@@ -603,14 +664,19 @@ modulationSpectrumFolder = function(
   }
 
   # prepare output
-  if (summary == TRUE) {
-    output = data.frame(
-      file = basename(filenames),
-      roughness = unlist(lapply(result, function(x) x$roughness))
-    )
+  if (!is.null(summaryFun) && any(!is.na(summaryFun))) {
+    result_sum = lapply(result, function(x) {
+      summarizeAnalyze(data.frame(roughness = x$roughness),
+                       summaryFun = summaryFun,
+                       var_noSummary = NULL)
+    })
+    output = cbind(data.frame(file = filenames_base),
+                   do.call(rbind, result_sum))
+    if (colnames(output)[2] == 'roughness_identity')
+      colnames(output)[2] = 'roughness'
   } else {
     output = result
-    names(output) = basename(filenames)
+    names(output) = filenames_base
   }
 
   if (htmlPlots & savePlots) {
@@ -636,8 +702,8 @@ modulationSpectrumFolder = function(
 #' @examples
 #' m = modulationSpectrum(soundgen(), samplingRate = 16000)$original
 #' soundgen:::getRough(m, roughRange = c(30, Inf))
-getRough = function(m, roughRange) {
-  colNames = abs(as.numeric(colnames(m)))
+getRough = function(m, roughRange, colNames = NULL) {
+  if (is.null(colNames)) colNames = abs(as.numeric(colnames(m)))
   rough_cols = which(colNames > roughRange[1] &
                        colNames < roughRange[2])
   if (length(rough_cols) > 0) {
