@@ -1153,10 +1153,9 @@ server = function(input, output, session) {
         samplingRate = input$samplingRate,
         wn = 'gaussian', windowLength = input$specWindowLength,
         step = round(input$specWindowLength / 4),
-        osc = input$osc == 'linear',
-        osc_dB = input$osc == 'dB',
+        osc = input$osc,
         heights = heights,
-        xlab = 'Time, ms', ylab = 'Frequency, kHz',
+        xlab = 'Time', ylab = 'Frequency, kHz',
         main = 'Spectrogram', contrast = input$specContrast,
         brightness = input$specBrightness,
         colorTheme = input$spec_colorTheme,
